/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JClass.java 6167 2012-02-09 16:46:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.metadata.structures;

import java.io.Serializable;
import java.util.Arrays;

/**
 * ASM class representation.
 * @author Gael Lalire
 */
public final class JClass implements Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -977433124031808986L;

    /**
     * version.
     */
    private int version;

    /**
     * access.
     */
    private int access;

    /**
     * name.
     */
    private String name;

    /**
     * signature.
     */
    private String signature;

    /**
     * superName.
     */
    private String superName;

    /**
     * interfaces.
     */
    private String[] interfaces;

    /**
     * Constructor.
     * @param version version
     * @param access access
     * @param name name
     * @param signature signature
     * @param superName superName
     * @param interfaces interfaces
     */
    public JClass(final int version, final int access, final String name, final String signature, final String superName,
            final String[] interfaces) {
        this.version = version;
        this.access = access;
        if (name == null) {
            throw new IllegalArgumentException("Name argument of JClass constructor can not be null");
        }
        this.name = name;
        this.signature = signature;
        if (superName == null) {
            throw new IllegalArgumentException("SuperName argument of JClass constructor can not be null");
        }
        this.superName = superName;
        String[] tmpInterfaces = interfaces;
        if (tmpInterfaces != null) {
            this.interfaces = tmpInterfaces.clone();
        } else {
            this.interfaces = null;
        }
    }

    /**
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * @return version
     */
    public int getVersion() {
        return version;
    }

    /**
     * @return access
     */
    public int getAccess() {
        return access;
    }

    /**
     * @return signature
     */
    public String getSignature() {
        return signature;
    }

    /**
     * @return superName
     */
    public String getSuperName() {
        return superName;
    }

    /**
     * @return interfaces
     */
    public String[] getInterfaces() {
        if (interfaces != null) {
            return interfaces.clone();
        }
        return null;
    }

    /**
     * @return name hascode
     */
    @Override
    public int hashCode() {
        return name.hashCode();
    }

    /**
     * @param obj the object to compare
     * @return true if equals
     */
    @Override
    public boolean equals(final Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof JClass)) {
            return false;
        } else {
            JClass jClass = (JClass) obj;
            if (version == jClass.version && access == jClass.access && name.equals(jClass.name)
                    && superName.equals(jClass.superName)
                    && Arrays.deepEquals(interfaces, jClass.interfaces)) {
                return true;
            }
            return false;
        }
    }

    /**
     * Returns a string representation of the class.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return name.replace('/', '.');
    }
}
